#!/bin/bash
if [[ -z $1 ]]; then
    echo "Usage: $0 <config_file>"
    exit 1
fi

lsusb -d 10c4:0003 |
while read line; 
do
    IFS=' '
    lsusblineArray=($line)
    
    busid=${lsusblineArray[1]}
    devid=${lsusblineArray[3]}
    
    echo "Found CommandIR on $busid and $devid"
    
    lsusb=`lsusb -vv -s $busid:$devid`

    IFS=$'\n'
    arrConfig=(`cat "$1"`);

    for ConfigLine in ${arrConfig[*]}
    do
        ConfigLineArray=($ConfigLine)

        IFS=','
        pattern=${ConfigLineArray[1]}

        expandedPattern=`echo -n -e "$pattern"`
        match=`expr match "$lsusb" ".*\($expandedPattern\).*"`

        if [[ -n "$match" ]]; then
            # Product found
            fwFile=${ConfigLineArray[2]}
            echo " Detected firmware $fwFile"
            
            fwIndex=${ConfigLineArray[0]}
            if [[ "$fwIndex" -ne "1" ]]; then
                # We don't have latest fw version installed
                newFwFile="/tmp/${ConfigLineArray[3]}"
                theMD5="${ConfigLineArray[4]}  $newFwFile"
                
                if [ ! -f "$newFwFile" ];
                then
                  wget "http://www.commandir.com/downloads/firmware/${ConfigLineArray[3]}" -O $newFwFile
                fi

                MD5Check=`md5sum $newFwFile`
                MD5Checks=($MD5Check)
                MD5CheckSum=${MD5Checks[0]}
                
                if [ "$theMD5" = "$MD5CheckSum" ]
                then
                  echo "MD5 match, calling CommandIR Firmware Updater sending $newFwFile to USB $busid:$devid"
                  commandir_firmware_updater $busid $devid $newFwFile Z
                else
                  echo "Invalid MD5 sum!"
                  rm "$newFwFile"
                fi

            else
                echo " Newest firmware installed."
            fi
        fi
    done
done

